window.Gleam.initSearch([{"doc":"glitr","title":"glitr","content":"# glitr\n\nGleam typed routes library for type-safe fullstack development\n\n[![Package Version](https://img.shields.io/hexpm/v/glitr)](https://hex.pm/packages/glitr)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glitr/)\n\n```sh\ngleam add glitr\n```\n```gleam\nimport glitr\nimport glitr/utils\nimport gleam/json\nimport gleam/dynamic\nimport gleam/http\n\npub type Todo {\n  Todo(id: String, title: String)\n}\n\nfn encoder(t: Todo) -&gt; json.Json {\n  json.object([\n    #(&quot;id&quot;, json.string(t.id)),\n    #(&quot;title&quot;, json.string(t.title)),\n  ])\n}\n\nfn decoder(\n  value: dynamic.Dynamic,\n) -&gt; Result(Todo, List(dynamic.DecodeError)) {\n  value\n  |&gt; dynamic.decode2(\n    Todo,\n    dynamic.field(&quot;id&quot;, dynamic.string),\n    dynamic.field(&quot;title&quot;, dynamic.string),\n  )\n}\n\npub fn main() {\n  let todo_converter = glitr.JsonConverter(encoder, decoder)\n  let get_all_todos_route = glitr.Route(\n    http.Get,\n    http.Http,\n    &quot;localhost&quot;,\n    2345,\n    False,\n    utils.simple_path_converter([&quot;todos&quot;]),\n    utils.no_body_converter(),\n    todo_converter\n  )\n\n  // This route can be shared and used by both frontend and backend applications\n\n  // Here is an example for a frontend application\n  let request = get_all_todos_route |&gt; utils.to_request(Nil, Nil)\n\n  // Use request as you wish (with glitr_lustre for example)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/glitr&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"glitr","title":"JsonConverter","content":"pub type JsonConverter(a) {\n  JsonConverter(encoder: JsonEncoder(a), decoder: JsonDecoder(a))\n}\n\nJsonConverter(encoder: JsonEncoder(a), decoder: JsonDecoder(a))\n\n\nSynonyms:\nglitr.JsonConverter\nglitr JsonConverter","url":"glitr.html#JsonConverter"},{"doc":"glitr","title":"JsonDecoder","content":"pub type JsonDecoder(a) =\n  fn(dynamic.Dynamic) -&gt; Result(a, List(dynamic.DecodeError))\n\n\nSynonyms:\nglitr.JsonDecoder\nglitr JsonDecoder","url":"glitr.html#JsonDecoder"},{"doc":"glitr","title":"JsonEncoder","content":"pub type JsonEncoder(a) =\n  fn(a) -&gt; json.Json\n\n\nSynonyms:\nglitr.JsonEncoder\nglitr JsonEncoder","url":"glitr.html#JsonEncoder"},{"doc":"glitr","title":"PathConverter","content":"pub type PathConverter(a) {\n  PathConverter(encoder: PathEncoder(a), decoder: PathDecoder(a))\n}\n\nPathConverter(encoder: PathEncoder(a), decoder: PathDecoder(a))\n\n\nSynonyms:\nglitr.PathConverter\nglitr PathConverter","url":"glitr.html#PathConverter"},{"doc":"glitr","title":"PathDecoder","content":"pub type PathDecoder(a) =\n  fn(List(String)) -&gt; Result(a, Nil)\n\n\nSynonyms:\nglitr.PathDecoder\nglitr PathDecoder","url":"glitr.html#PathDecoder"},{"doc":"glitr","title":"PathEncoder","content":"pub type PathEncoder(a) =\n  fn(a) -&gt; List(String)\n\n\nSynonyms:\nglitr.PathEncoder\nglitr PathEncoder","url":"glitr.html#PathEncoder"},{"doc":"glitr","title":"QueryConverter","content":"pub type QueryConverter(a) {\n  QueryConverter(\n    encoder: QueryEncoder(a),\n    decoder: QueryDecoder(a),\n  )\n}\n\nQueryConverter(\n  encoder: QueryEncoder(a),\n  decoder: QueryDecoder(a),\n)\n\n\nSynonyms:\nglitr.QueryConverter\nglitr QueryConverter","url":"glitr.html#QueryConverter"},{"doc":"glitr","title":"QueryDecoder","content":"pub type QueryDecoder(a) =\n  fn(List(#(String, String))) -&gt; Result(a, Nil)\n\n\nSynonyms:\nglitr.QueryDecoder\nglitr QueryDecoder","url":"glitr.html#QueryDecoder"},{"doc":"glitr","title":"QueryEncoder","content":"pub type QueryEncoder(a) =\n  fn(a) -&gt; List(#(String, String))\n\n\nSynonyms:\nglitr.QueryEncoder\nglitr QueryEncoder","url":"glitr.html#QueryEncoder"},{"doc":"glitr","title":"Route","content":"pub type Route(\n  path_type,\n  query_type,\n  req_body_type,\n  res_body_type,\n) {\n  Route(\n    method: http.Method,\n    scheme: http.Scheme,\n    host: String,\n    port: Int,\n    has_body: Bool,\n    path_converter: PathConverter(path_type),\n    query_converter: QueryConverter(query_type),\n    req_body_converter: JsonConverter(req_body_type),\n    res_body_converter: JsonConverter(res_body_type),\n  )\n}\n\nRoute(\n  method: http.Method,\n  scheme: http.Scheme,\n  host: String,\n  port: Int,\n  has_body: Bool,\n  path_converter: PathConverter(path_type),\n  query_converter: QueryConverter(query_type),\n  req_body_converter: JsonConverter(req_body_type),\n  res_body_converter: JsonConverter(res_body_type),\n)\n\n\nSynonyms:\nglitr.Route\nglitr Route","url":"glitr.html#Route"},{"doc":"glitr","title":"RouteOptions","content":"pub type RouteOptions(p, q, b) {\n  RouteOptions(path: p, query: q, body: b)\n}\n\nRouteOptions(path: p, query: q, body: b)\n\n\nSynonyms:\nglitr.RouteOptions\nglitr RouteOptions","url":"glitr.html#RouteOptions"},{"doc":"glitr","title":"glitr","content":"","url":"glitr.html"},{"doc":"glitr/utils","title":"id_path_converter","content":"pub fn id_path_converter(\n  root: List(String),\n) -&gt; PathConverter(String)\n\nSynonyms:\nglitr/utils.id_path_converter\nglitr/utils id_path_converter","url":"glitr/utils.html#id_path_converter"},{"doc":"glitr/utils","title":"no_body_converter","content":"pub fn no_body_converter() -&gt; JsonConverter(Nil)\n\nSynonyms:\nglitr/utils.no_body_converter\nglitr/utils no_body_converter","url":"glitr/utils.html#no_body_converter"},{"doc":"glitr/utils","title":"no_query_converter","content":"pub fn no_query_converter() -&gt; QueryConverter(Nil)\n\nSynonyms:\nglitr/utils.no_query_converter\nglitr/utils no_query_converter","url":"glitr/utils.html#no_query_converter"},{"doc":"glitr/utils","title":"simple_path_converter","content":"pub fn simple_path_converter(\n  root: List(String),\n) -&gt; PathConverter(Nil)\n\nSynonyms:\nglitr/utils.simple_path_converter\nglitr/utils simple_path_converter","url":"glitr/utils.html#simple_path_converter"},{"doc":"glitr/utils","title":"to_request","content":"pub fn to_request(\n  route: Route(a, b, c, d),\n  path: a,\n  query: b,\n  body: c,\n) -&gt; Request(String)\n\nSynonyms:\nglitr/utils.to_request\nglitr/utils to_request","url":"glitr/utils.html#to_request"},{"doc":"glitr/utils","title":"glitr/utils","content":"","url":"glitr/utils.html"},{"doc":"glitr/route","title":"new","content":"pub fn new() -&gt; Route(Nil, Nil, Nil, Nil)\n\nSynonyms:\nglitr/route.new\nglitr/route new","url":"glitr/route.html#new"},{"doc":"glitr/route","title":"with_has_body","content":"pub fn with_has_body(\n  route: Route(a, b, c, d),\n  has_body: Bool,\n) -&gt; Route(a, b, c, d)\n\nSynonyms:\nglitr/route.with_has_body\nglitr/route with_has_body","url":"glitr/route.html#with_has_body"},{"doc":"glitr/route","title":"with_host","content":"pub fn with_host(\n  route: Route(a, b, c, d),\n  host: String,\n) -&gt; Route(a, b, c, d)\n\nSynonyms:\nglitr/route.with_host\nglitr/route with_host","url":"glitr/route.html#with_host"},{"doc":"glitr/route","title":"with_method","content":"pub fn with_method(\n  route: Route(a, b, c, d),\n  method: Method,\n) -&gt; Route(a, b, c, d)\n\nSynonyms:\nglitr/route.with_method\nglitr/route with_method","url":"glitr/route.html#with_method"},{"doc":"glitr/route","title":"with_path_converter","content":"pub fn with_path_converter(\n  route: Route(a, b, c, d),\n  path_converter: PathConverter(e),\n) -&gt; Route(e, b, c, d)\n\nSynonyms:\nglitr/route.with_path_converter\nglitr/route with_path_converter","url":"glitr/route.html#with_path_converter"},{"doc":"glitr/route","title":"with_port","content":"pub fn with_port(\n  route: Route(a, b, c, d),\n  port: Int,\n) -&gt; Route(a, b, c, d)\n\nSynonyms:\nglitr/route.with_port\nglitr/route with_port","url":"glitr/route.html#with_port"},{"doc":"glitr/route","title":"with_query_converter","content":"pub fn with_query_converter(\n  route: Route(a, b, c, d),\n  query_converter: QueryConverter(e),\n) -&gt; Route(a, e, c, d)\n\nSynonyms:\nglitr/route.with_query_converter\nglitr/route with_query_converter","url":"glitr/route.html#with_query_converter"},{"doc":"glitr/route","title":"with_request_body_converter","content":"pub fn with_request_body_converter(\n  route: Route(a, b, c, d),\n  req_body_converter: JsonConverter(e),\n) -&gt; Route(a, b, e, d)\n\nSynonyms:\nglitr/route.with_request_body_converter\nglitr/route with_request_body_converter","url":"glitr/route.html#with_request_body_converter"},{"doc":"glitr/route","title":"with_response_body_converter","content":"pub fn with_response_body_converter(\n  route: Route(a, b, c, d),\n  res_body_converter: JsonConverter(e),\n) -&gt; Route(a, b, c, e)\n\nSynonyms:\nglitr/route.with_response_body_converter\nglitr/route with_response_body_converter","url":"glitr/route.html#with_response_body_converter"},{"doc":"glitr/route","title":"with_scheme","content":"pub fn with_scheme(\n  route: Route(a, b, c, d),\n  scheme: Scheme,\n) -&gt; Route(a, b, c, d)\n\nSynonyms:\nglitr/route.with_scheme\nglitr/route with_scheme","url":"glitr/route.html#with_scheme"},{"doc":"glitr/route","title":"glitr/route","content":"","url":"glitr/route.html"}]);